//ssr 配置
import app from "./server.dev";
import React from "react";
import { StaticRouter } from "react-router";
import App from "../src/App";
import createAppStore from "../src/store";
import { useStaticRendering, Provider } from "mobx-react";

const path = require("path");
const koaStatic = require("koa-static");
const render = require("koa-art-template");
const ReactDOMServer = require("react-dom/server");

useStaticRendering(true);

app.use(
    koaStatic(path.join(__dirname, "../build"), {
        maxage: 1e3 * 60 * 60 * 5
    })
);

render(app, {
    root: path.join(__dirname, "../build"),
    extname: ".html",
    debug: process.env.NODE_ENV.includes("development")
});

app.use(async (ctx, next) => {
    await next();
    const context = {};
    const store = createAppStore({}, ctx);
    const html = ReactDOMServer.renderToString(
        <StaticRouter location={ctx.req.url} context={context}>
            <Provider store={store}>
                <App />
            </Provider>
        </StaticRouter>
    );
    console.warn("renderToString", ctx.request.url, context);
    // context.url will contain the URL to redirect to if a <Redirect> was used
    if (context.url) {
        ctx.status = 302;
        ctx.redirect(context.url);
    } else {
        await ctx.render("index", {
            content: html,
            ssrScript: "<script>window.IS_SSR = true;</script>"
        });
    }
});
