import axios from "axios";
import Qs from "qs";
import { showError, isSSR } from "@/util";

let store = null;
//ssr后属于同源 不需要配置
let baseURL = null;
let self = global || window;
if (self.location && !isSSR()) {
    if (self.location.port === "3000") {
        baseURL = `//${self.location.hostname}:1024/`;
    } else if (self.location.host.match("test")) {
        baseURL = "//test-api-hr.duowan.com";
    } else {
        baseURL = "//api-hr.duowan.com";
    }
}
let axConfig = {
    headers: { "Content-Type": "application/x-www-form-urlencoded" },
    transformRequest: [
        function(data, headers) {
            data = Qs.stringify(data);
            return data;
        }
    ],
    transformResponse: [],
    withCredentials: true
};
baseURL && (axConfig.baseURL = baseURL);
let ax = axios.create(axConfig);

ax.interceptors.request.use(
    config => {
        let param = config.method === "post" ? config.data : config.params;
        if (param && param.needAuth) {
            if (!(store.userId && store.token)) {
                showError("登录态失效，请重新登录");
                store.logout();
                return Promise.reject("请先登录");
            }
        }
        return config;
    },
    error => {
        // 对请求错误做些什么
        return Promise.reject(error);
    }
);

// 拦截器处理错误
ax.interceptors.response.use(
    response => {
        if (response.data.code === 0) {
            return Promise.resolve(response.data);
        } else if (response.data.code === -5) {
            showError(response.data.msg);
            store.logout();
        } else {
            return Promise.reject(new Error(response.data.msg));
        }
    },
    error => {
        return Promise.reject(error);
    }
);
function setStore(_store) {
    store = _store;
}
export { ax, setStore };
