import { observable, action } from "mobx";
import history from "@/router/history";
import Cookies from "js-cookie";
class AppStore {
    @observable userId;
    @observable token;
    @observable departmentList;
    @observable departmentMap;

    constructor(initialState = {}, ctx) {
        this.userId =
            initialState.userId || ctx
                ? ctx.cookies.get("hr_userId")
                : Cookies.get("hr_userId");

        this.token =
            initialState.token || ctx
                ? ctx.cookies.get("hr_token")
                : Cookies.get("hr_token");

        this.departmentList = initialState.departmentList || [];
        this.departmentMap = initialState.initialState || {};
    }

    @action
    login() {
        this.userId = Cookies.get("hr_userId");
        this.token = Cookies.get("hr_token");
    }

    @action
    logout() {
        let path = "/login";
        this.userId = undefined;
        this.token = undefined;
        history.push(path);
    }

    @action
    setDepartmentList(list) {
        let listMap = {};
        list.forEach(item => {
            listMap[item.id] = item.name;
        });
        this.departmentMap = listMap;
        this.departmentList = list;
    }
}
export default function createAppStore(initialState, ctx) {
    return new AppStore(initialState, ctx);
}
